pecos.tools.pseudo\_threshold\_tools
====================================

.. automodule:: pecos.tools.pseudo_threshold_tools

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      find_polyfit
      find_pseudo
      find_uniscalefit
      ns2nsfit
      plot
      pseudo_threshold_code_capacity
   
   

   
   
   

   
   
   



